[Pkg-mozext-commits] [firebug] 11/30: Issue 7530: Toolbars are huge in combination with "Theme Font & Size Changer"

David Prévot taffit at moszumanska.debian.org
Fri Jun 20 22:34:24 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository firebug.

commit 0df0911a0eb048de72f22b7692528f44503f95f5
Author: Simon Lindholm <simon.lindholm10 at gmail.com>
Date:   Sun Jun 15 23:23:14 2014 +0200

    Issue 7530: Toolbars are huge in combination with "Theme Font & Size Changer"
    
    https://code.google.com/p/fbug/issues/detail?id=7530
---
 extension/content/firebug/chrome/chrome.js | 7 ++++---
 extension/skin/classic/firebug.css         | 8 ++++----
 extension/skin/classic/mac/firebug.css     | 8 ++++----
 3 files changed, 12 insertions(+), 11 deletions(-)

diff --git a/extension/skin/classic/firebug.css b/extension/skin/classic/firebug.css
index 130e1de..d57013a 100644
--- a/extension/skin/classic/firebug.css
+++ b/extension/skin/classic/firebug.css
@@ -63,7 +63,7 @@
     padding-left: 27px;
     padding: 1px 0;
     border-bottom: 1px solid rgba(10, 31, 51, 0.35);
-    height: calc(20rem + 8px);
+    height: calc(2rem + 8px);
 }
 
 #fbToggleCommandEditorBox {
@@ -147,7 +147,7 @@
     -moz-box-align: center;
     overflow: hidden;
     padding: 1px 0;
-    height: calc(20rem + 7px);
+    height: calc(2rem + 7px);
 }
 
 #fbToolbarInner > hbox {
@@ -155,7 +155,7 @@
 }
 
 .panelTabBox {
-    height: calc(20rem + 8px);
+    height: calc(2rem + 8px);
     padding: 0;
     overflow: hidden;
 }
@@ -296,7 +296,7 @@ panelTab[selected="true"][disabled="true"] {
 
 #fbPanelSplitter > #fbPanelSplitterBox {
     visibility: visible;
-    height: calc(20rem + 8px);
+    height: calc(2rem + 8px);
     width: 6px;
     background-color: -moz-dialog;
     background-image: linear-gradient(rgba(255, 255, 255, 0.9), rgba(255, 255, 255, 0.2));
diff --git a/extension/skin/classic/mac/firebug.css b/extension/skin/classic/mac/firebug.css
index faf8cdf..43f64d4 100644
--- a/extension/skin/classic/mac/firebug.css
+++ b/extension/skin/classic/mac/firebug.css
@@ -10,7 +10,7 @@
 #fbCommandToolbar {
     font-size: 11px;
     border: none;
-    height: calc(22rem + 10px);
+    height: calc(2.2rem + 10px);
     padding: 0 0 0 7px !important;
 }
 
@@ -44,7 +44,7 @@
 
 #fbPanelSplitter > #fbPanelSplitterBox {
     visibility: visible;
-    height: calc(22rem + 10px);
+    height: calc(2.2rem + 10px);
     width: 6px;
     background-color: -moz-dialog;
     cursor: default;
@@ -98,14 +98,14 @@
 
 #fbPanelBar1-tabBox,
 #fbPanelBar2-tabBox {
-    height: calc(22rem + 10px);
+    height: calc(2.2rem + 10px);
 }
 
 /* ensure the inner toolbar background looks the same as the other toolbars */
 #fbToolbarInner.innerToolbar {
     -moz-margin-start: -5px;
     -moz-margin-end: 0;
-    height: calc(22rem + 9px);
+    height: calc(2.2rem + 9px);
     background-color: transparent;
 }
 

diff --git a/extension/content/firebug/chrome/chrome.js b/extension/content/firebug/chrome/chrome.js
index cf49ed7..0463e73 100644
--- a/extension/content/firebug/chrome/chrome.js
+++ b/extension/content/firebug/chrome/chrome.js
@@ -1235,10 +1235,11 @@ var FirebugChrome =
         {
             // Set the relative font size of the root element (<html> or <window>)
             // so that 'rem' units can be used for sizing relative to the font size.
             // 1rem equals 1px times the zoom level. This doesn't affect any of the
             // UI, because <body>, #fbContentBox, etc. override the font-size.
-
-            doc.documentElement.style.fontSize = zoom + "px";
+            // Do set if to some reasonable font-size, though, so we don't break
+            // completely with extensions like "Theme Font & Size Changer".
+            doc.documentElement.style.fontSize = (zoom*10) + "px";
         };
 
         // scale the aspect relative to 11pt Lucida Grande
@@ -1235,10 +1235,11 @@ var FirebugChrome =
             // Set the relative font size of the root element (<html> or <window>)
             // so that 'rem' units can be used for sizing relative to the font size.
-            // 1rem equals 1px times the zoom level. This doesn't affect any of the
+            // 1rem equals 10px times the zoom level. This doesn't affect any of the
             // UI, because <body>, #fbContentBox, etc. override the font-size.
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/firebug.git



More information about the Pkg-mozext-commits mailing list